# Program to generate a plot energy level diagram for H (Bohr atomic model) using matplotlib and numpy
#
# Dr. Walter F. de Azevedo Jr.
# https://azevedolab.net/
# Porto Alegre, April 17, 2019

# Import libraries
import matplotlib.pyplot as plt
import numpy as np

# Define parameters
h = 6.626070040e-34     # Planck constant in J.s (source: https://physics.nist.gov/cgi-bin/cuu/Value?h)
h_bar = h/(2*np.pi)     # h bar in J.s
m = 9.10938356e-31      # Mass of electron in Kg (source: https://physics.nist.gov/cgi-bin/cuu/Value?me|search_for=electron+mass)
e = 1.60217652e-19      # Charge of an electron
epsilon_0 = 8.854187817e-12 # Vacuum permittivity in C**2/(N.m**2)

# Atomic number
Z = 1

# Define x range with linspace
x1 = np.linspace(0,10,500)

# Set up x-axis limits 
plt.xlim(0.0,5.0*e)

# Set up y-axis limits
plt.ylim(-20.0*e,5.0*e)

# Add labels
plt.ylabel('Energy ($10^{-18}$J)',fontsize=24)                         # Add axis label
plt.title('Energy Level Diagram for H (Z=1)\n(Bohr Atomic Model)')     # Add title

# Looping through energy levels (in Joules)
print("Level\t  Energy(J)")
for n in range(1,7):
    # Calculate E
    E = (-m*(Z**2)*(e**4))/(2*(4*np.pi*epsilon_0*h_bar*n)**2)   # Equation for energy
    print(n,"\t\t",E)
    y1 = np.linspace(E,E,500)
    plt.plot(x1,y1)

# Hide ticks on x
ax = plt.axes()
ax.xaxis.set_major_formatter(plt.NullFormatter())

# Show plot
plt.show()

# Save plot on png file
plt.savefig("energy_diagram.png")