# This program carries out the numerical integration of finite-square well potential
#
# Dr. Walter F. de Azevedo Jr.
# Porto Alegre, April 16, 2019

# Import libraries
import numpy as np
import matplotlib.pyplot as plt

# Define initial parameters
alpha = 0.1
u_min = 0.0
u_max = 1.0
n = 21

# Define x range with linspace
u = np.linspace(u_min,u_max,n)

# Define array
psi = np.ones(n)
d_psi = np.zeros(n)
c = np.zeros(n)

# Define psi[0] and d_psi[0]
psi[0] = 1.0
d_psi[0] = 0.0
c[0] = -64*alpha

# Show intial values
print("u\tpsi(i)")
print(u[0],"\t",psi[0])

# looping through u
for i in range(1,n):

    # Test c(u)
    if u[i] > -0.5 and u[i] < 0.5:
        c[i] = -64*alpha
    else:
        c[i] = 64*(1-alpha)

    # Calculate psi
    psi[i] = psi[i-1] + d_psi[i-1]*(u[i]-u[i-1])

    # Calculate d_psi
    d_psi[i] = d_psi[i-1] + c[i-1]*psi[i-1]*(u[i]-u[i-1])

    # Show results for each iteration
    print(u[i],"\t",psi[i])

# Set up x-axis limits
plt.xlim(u_min,u_max)

# Set up grid
plt.grid(True)

# Add labels
plt.xlabel('u',fontsize=14)                         # Add axis label
plt.ylabel('$\psi$',fontsize=24)                    # Add axis label
plt.title('Finite-square well potential')           # Add title

# Create plots
plt.plot(u,psi)
plt.plot(u,psi, 'ro')

# Show plot
plt.show()

# Save plot on png file
plt.savefig("finite_square_potential.png")